import $ from 'jquery';
require('selectize.js/dist/js/selectize');

require('./ep-tecdoc.scss');

$(function() {
    let $form = $('#tecdoc-woo-form'),
        $selected = $('.selected-vehicle'),

        $manufacturers = $('#tecdoc-woo-manufacturer'),
        $models = $('#tecdoc-woo-model'),
        $vehicles = $('#tecdoc-woo-type'),
        $shopButton = $('#tecdoc-submit');

    function ajaxRequest(action, callback, params) {
        params = params || {};
        params.action = action;

        $.ajax({
            url: tecdoc_settings_object.ajax_url,
            data: params,
            method: 'POST',
            success: callback
        });
    }

    function getCookie(name) {
        var cookies = {};

        document.cookie.split(';').forEach(function (item) {
            item = item.split('=');
            cookies[item[0].replace(/^\s+|\s+$/, '')] = item[1];
        });

        if (typeof cookies[name] !== 'undefined') {
            return cookies[name];
        }

        return null;
    }

    function setCookie(name, value) {
        var date = new Date(new Date().setFullYear(new Date().getFullYear() + 1));
        document.cookie = name + '=' + value + ';path=/;expires=' + date.toUTCString();
    }

    function clearCookie(name) {
        document.cookie = name + '=;path=/;expires=Thu, 01 Jan 1970 00:00:00 GMT';
    }

    function startLoad($elem) {
        var $holder = $elem.closest('.holder'),
            $loader = $holder.find('.loader');

        hideElem($elem);
        $loader.removeClass('hidden');
    }

    function hideElem($elem) {
        $elem.closest('.col-inner').addClass('hidden');
    }

    function stopLoad($elem) {
        var $holder = $elem.closest('.holder'),
            $loader = $holder.find('.loader');

        $loader.addClass('hidden');
        showElem($elem);
    }

    function showElem($elem) {
        $elem.closest('.col-inner').removeClass('hidden');
    }

    function initManufacturers() {
        $manufacturers.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'featured', label: 'Izdvojeni proizvođači', label_sele: ''},
                {value: 'rest', label: 'Svi proizvođači', label_sele: ''}
            ],
            valueField: 'id',
            labelField: 'name',
            render: {
                optgroup_header: function (data, escape) {
                    return '<div class="optgroup-header">' + escape(data.label) + '</div>';
                }
            },
            maxItems: 1,
            searchField: 'name',
            lockOptgroupOrder: true,
            create: false,
            preload: true
        });

        loadManufacturers();
    }

    function loadManufacturers() {
        $manufacturers.off('change');

        ajaxRequest('tecdoc_get_manufacturers', function (data) {
            var selectize = $manufacturers[0].selectize,
                selected = parseInt(getCookie('manufacturerId'));

            selectize.addOption(data);
            stopLoad($manufacturers);

            if (selected) {
                selectize.setValue(selected);
            } else {
                selectize.focus();
            }

            $manufacturers.on('change', function () {
                loadModels(this.value);
            });
        });
    }

    function initModels() {
        $models.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'default', label: '', label_sele: ''}
            ],
            valueField: 'id',
            labelField: 'name',
            render: {
                optgroup_header: function () {
                    return '<div class="model thead">' +
                        '<div class="name">Model</div>' +
                        '<div class="year">Godina</div>' +
                        '</div>';
                },
                item: function (item, escape) {
                    return '<div class="model tbody">' +
                        '<div class="name">' + escape(item.name) + '</div>' +
                        '</div>';
                },
                option: function (item, escape) {
                    return '<div class="model">' +
                        '<div class="name">' + escape(item.name) + '</div>' +
                        '<div class="year">' + escape(item.year) + '</div>' +
                        '</div>';
                }
            },
            searchField: 'name'
        });
    }

    function loadModels(manufacturerId) {
        $models.off('change');

        var selectize = $models[0].selectize,
            selected = parseInt(getCookie('modelId'));

        selectize.disable();
        selectize.clearOptions();
        startLoad($models);

        if (manufacturerId) {
            ajaxRequest('tecdoc_get_models', function (data) {
                selectize.addOption(data);
                selectize.enable();
                stopLoad($models);

                if (selected) {
                    selectize.setValue(selected);
                } else {
                    selectize.focus();
                }

                $models.on('change', function () {
                    loadVehicles(parseInt($manufacturers.val()), this.value);
                });
            }, {
                manufacturerId: parseInt(manufacturerId)
            });
        }
    }

    function initVehicles() {
        $vehicles.selectize({
            optgroupField: 'group',
            optgroups: [
                {value: 'default', label: '', label_sele: ''}
            ],
            valueField: 'slug',
            labelField: 'name',
            searchField: 'name',
            render: {
                optgroup_header: function () {
                    return '<div class="model thead">' +
                        '<div class="type">Tip</div>' +
                        '<div class="motor_type">Motor Type</div>' +
                        '<div class="power">Snaga</div>' +
                        '</div>';
                },
                item: function (item, escape) {
                    return '<div>' + escape(item.name) + ' - ' + escape(item.engine) + ' ' + escape(item.power) + '</div>';
                },
                option: function (item, escape) {
                    return '<div class="model">' +
                        '<div class="type">' + escape(item.name) + '</div>' +
                        '<div class="motor_type">' + escape(item.engine) + '</div>' +
                        '<div class="power">' + escape(item.power) + '</div>' +
                        '</div>';
                }
            }
        });
    }

    function loadVehicles(manufacturerId, modelId) {
        $vehicles.off('change');

        var selectize = $vehicles[0].selectize,
            selected = parseInt(getCookie('vehicleId'));

        selectize.disable();
        selectize.clearOptions();
        startLoad($vehicles);

        if (manufacturerId && modelId) {
            ajaxRequest('tecdoc_get_vehicles', function (data) {
                selectize.addOption(data);
                selectize.enable();
                stopLoad($vehicles);

                if (selected) {
                    selectize.setValue(selected);
                    $shopButton.removeClass('disabled');
                } else {
                    selectize.focus();
                }

                $vehicles.on('change', function () {
                    if (this.value) {
                        setCookie('_tecdoc', this.value);
                        $shopButton.removeClass('disabled');
                        goShop();
                    } else {
                        clearCookie('_tecdoc');
                        $shopButton.addClass('disabled');
                    }
                });
            }, {
                manufacturerId: manufacturerId,
                modelId: modelId
            });
        }
    }

    function goShop() {
        $shopButton.find('.loader-wrapper, .loader').removeClass('hidden');
        $shopButton.addClass('disabled');
        setTimeout(function () {
            document.location.href = $shopButton.attr('href');
        }, 0);
    }

    $(document).on('click', '.shop-link', function (e) {
        e.preventDefault();
        var $link = $(this);
        $link.find('.loader-wrapper, .loader').removeClass('hidden');
        setTimeout(function () {
            document.location.href = $link.attr('href');
        }, 0);
    });

    function displayVehicle() {
        $form.addClass('hidden');
        $selected.removeClass('hidden');

        ajaxRequest('tecdoc_vehicle', function (data) {
            if (data !== '0') {
                $selected.find('.selected-vehicle-display').html(data);

                if ($selected.find('img').length > 0) {
                    $selected.addClass('has-image');
                } else {
                    $selected.removeClass('has-image');
                }

                $selected.find('.selected-vehicle-change').on('click', function () {
                    clearCookie('_tecdoc');
                    initForm();

                    $selected.addClass('hidden');
                    $form.removeClass('hidden');
                    $manufacturers[0].selectize.focus();
                });
            } else {
                clearCookie('_tecdoc');
                initForm();
            }
        });
    }

    function initForm() {
        initManufacturers();
        initModels();
        initVehicles();
        $selected.addClass('hidden');
        $form.removeClass('hidden');
        $form.css('opacity', 1);
    }

    if (getCookie('_tecdoc')) {
        displayVehicle();
    } else {
        initForm();
    }

    var TECDOC_HAK_COUPON = tecdoc_settings_object && typeof tecdoc_settings_object.hak_coupon_text !== 'undefined' ? tecdoc_settings_object.hak_coupon_text : 'Hak popust',
        TECDOC_SITEURL = tecdoc_settings_object && typeof tecdoc_settings_object.siteurl !== 'undefined'
            ? tecdoc_settings_object.siteurl
            : 'unknown site url',
        HAK_STRING_SUCCESSMESSAGE = tecdoc_settings_object && typeof tecdoc_settings_object.success !== 'undefined' ? tecdoc_settings_object.success : 'Active user!',
        HAK_STRING_ERRORMESSAGE = tecdoc_settings_object && typeof tecdoc_settings_object.error !== 'undefined' ? tecdoc_settings_object.error : 'Inactive user or wrong input data!',
        memberIdVal = '';

    /**
     * Initialize HAK API triggers
     */
    function initHakAPIIntegration() {
        var hakOptionsElem = '#hak_options';

        if ($(hakOptionsElem).length !== 0) {
            $(hakOptionsElem).change(function () {
                if ($(this).val() == 'yes') {
                    $(".hak_memberid").removeClass('hidden');
                    $("#hak_memberID_field").append('<span class="response"></span>');
                    $("#hak_memberID_field").append('<div class="loader hidden"></div>');
                } else {
                    $(".hak_memberid").addClass('hidden');
                }
            });
        }

        var hakMemberIdElem = '#hak_memberID',
            memberIDVal = '';

        if ($(hakOptionsElem).length !== 0) {
            $(hakMemberIdElem).keyup(function () {
                if ($(this).val() == "") {
                    $(".response").html(' ');
                }

                var memberName = $('#billing_first_name').val(),
                    memberLast = $('#billing_last_name').val(),
                    memberIDValLen = $(this).val().length;

                if (!isNaN($(this).val())) {
                    memberIDVal = $(this).val();
                } else {
                    var lastChar = memberIDVal.substr(0, memberIDVal.length);
                    $(this).val(lastChar);
                }
                if (
                    (memberIDValLen == 9) &&
                    ( memberIDVal != undefined && memberIDVal != "" && isNaN(memberIDVal) == false) &&
                    (memberName != "" && memberLast != "" && isNaN(memberName) && isNaN(memberLast))
                ) {
                    hakAPI(memberIDVal, memberName, memberLast); // call HAK API Handler
                }
            });
        }
    }

    function hakAPI(memberIDVal, memberName, memberLast) {
        var data = {
            memberId: memberIDVal, //example: 278710382
            memberFirstName: memberName,
            memberLastName: memberLast,
            hak_coupon: TECDOC_HAK_COUPON
        };

        $.ajax({
            async: true,
            crossDomain: true,
            url: TECDOC_SITEURL + '/wp-json/hak/members',
            method: 'POST',
            processData: true,
            data: data,
            beforeSend: function () {
                $("#hak_memberID_field .loader").removeClass('hidden');
            },
            success: function (data) {
                $("#hak_memberID_field .loader").addClass('hidden');

                if (data[0].success && data[0].success != undefined) {
                    $(".response").html(' ');
                    $(".response").removeClass('error');
                    $(".response").addClass('success');
                    $(".response").html(HAK_STRING_SUCCESSMESSAGE);
                    jQuery('body').trigger('update_checkout');
                } else {
                    $(".response").html(' ');
                    $(".response").removeClass('success');
                    $(".response").addClass('error');
                    $(".response").html(HAK_STRING_ERRORMESSAGE);
                }
            },
            error: function (x, status, error) {
                console.log("An error occurred: " + status + "nError: " + error);
            }
        });
    }

    initHakAPIIntegration();
});