<?php

class tecdocWooSettings
{
    private $tecdoc_settings__options;

    public function __construct()
    {
        add_action('admin_menu', array( $this, 'tecdoc_settings__add_plugin_page' ));
        add_action('admin_init', array( $this, 'tecdoc_settings__page_init' ));
    }

    public function tecdoc_settings__add_plugin_page()
    {
        add_menu_page(
            'TecDoc Settings ', // page_title
            'TecDoc Settings ', // menu_title
            'manage_options', // capability
            'tecdoc-settings', // menu_slug
            array( $this, 'tecdoc_settings__create_admin_page' ), // function
            'dashicons-admin-generic', // icon_url
            3 // position
        );
    }

    public function tecdoc_settings__create_admin_page()
    {
        $this->tecdoc_settings__options = get_option('tecdoc_settings__option_name'); ?>

        <div class="wrap">
            <h2><?php _e('TecDoc Settings', 'tecdoc-woo'); ?></h2>
            <p><?php _e('TecDoc settings according to TecDoc web service.', 'tecdoc-woo'); ?><br>
            <?php _e('For more information please visit: <a href="http://webservicepilot.tecdoc.net/pegasus-3-0/info/index.html" target="_blank">http://webservicepilot.tecdoc.net/pegasus-3-0/info/index.html<a>', 'tecdoc-woo'); ?></p>
            <?php settings_errors(); ?>

            <form method="post" action="options.php">
                <?php
                    settings_fields('tecdoc_settings__option_group');
                    do_settings_sections('tecdoc-settings-admin');
                    submit_button();
                ?>
            </form>
        </div>
    <?php }

    public function tecdoc_settings__page_init()
    {
        register_setting(
            'tecdoc_settings__option_group', // option_group
            'tecdoc_settings__option_name', // option_name
            array( $this, 'tecdoc_settings__sanitize' ) // sanitize_callback
        );

        add_settings_section(
            'tecdoc_settings__setting_section', // id
            'Settings', // title
            array( $this, 'tecdoc_settings__section_info' ), // callback
            'tecdoc-settings-admin' // page
        );

        add_settings_field(
            'country_code_according_to_iso_3166_0', // id
            'Country code according to ISO 3166', // title
            array( $this, 'country_code_according_to_iso_3166_0_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'language_code_according_to_iso_639_1', // id
            'Language code according to ISO 639', // title
            array( $this, 'language_code_according_to_iso_639_1_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'tecdoc_provider_id_2', // id
            'TecDoc Provider ID', // title
            array( $this, 'tecdoc_provider_id_2_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'tecdoc_vehicle_type_3', // id
            'TecDoc Vehicle Type ', // title
            array( $this, 'tecdoc_vehicle_type_3_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'featured_manufacturer_id_4', // id
            'Featured Manufacturer ID-s<sup>*</sup>', // title
            array( $this, 'featured_manufacturer_id_4_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'exclude_manufacturer_id_11', // id
            'Exclude Manufacturer ID-s<sup>*</sup>', // title
            array( $this, 'exclude_manufacturer_id_11_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'featured_manufacturer_checkbox_id_5', // id
            'Limit manufacturer display', // title
            array( $this, 'featured_manufacturer_checkbox_id_5_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'brand_list_id_6', // id
            'Supported brand ID-s<sup>*</sup>', // title
            array( $this, 'brand_list_id_6_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'searchexact_id_7', // id
            'Search mode<sup>*</sup>', // title
            array( $this, 'searchexact_id_7_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'tecdoc_root_cat_id_8', // id
            'TecDoc root category ID', // title
            array( $this, 'tecdoc_root_cat_id_8_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'single_product_compatible_cars_9', // id
            'Display compatible cars list for a product', // title
            array( $this, 'single_product_compatible_cars_9_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'tecdoc_api_base_url_10', // id
            'TecDoc API Base URL', // title
            array( $this, 'tecdoc_api_base_url_10_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );

        add_settings_field(
            'hak_input_id_12', // id
            'HAK coupon name<sup>*</sup>', // title
            array( $this, 'hak_input_id_12_callback' ), // callback
            'tecdoc-settings-admin', // page
            'tecdoc_settings__setting_section' // section
        );
    }

    public function tecdoc_settings__sanitize($input)
    {
        $sanitary_values = array();
        if (isset($input['country_code_according_to_iso_3166_0'])) {
            $sanitary_values['country_code_according_to_iso_3166_0'] = sanitize_text_field($input['country_code_according_to_iso_3166_0']);
        }

        if (isset($input['language_code_according_to_iso_639_1'])) {
            $sanitary_values['language_code_according_to_iso_639_1'] = sanitize_text_field($input['language_code_according_to_iso_639_1']);
        }

        if (isset($input['tecdoc_provider_id_2'])) {
            $sanitary_values['tecdoc_provider_id_2'] = sanitize_text_field($input['tecdoc_provider_id_2']);
        }

        if (isset($input['tecdoc_vehicle_type_3'])) {
            $sanitary_values['tecdoc_vehicle_type_3'] = sanitize_text_field($input['tecdoc_vehicle_type_3']);
        }

        if (isset($input['featured_manufacturer_id_4'])) {
            $sanitary_values['featured_manufacturer_id_4'] = sanitize_text_field($input['featured_manufacturer_id_4']);
        }

        if (isset($input['featured_manufacturer_checkbox_id_5'])) {
            $sanitary_values['featured_manufacturer_checkbox_id_5'] = sanitize_text_field($input['featured_manufacturer_checkbox_id_5']);
        }

        if (isset($input['brand_list_id_6'])) {
            $sanitary_values['brand_list_id_6'] = sanitize_text_field($input['brand_list_id_6']);
        }

        if (isset($input['searchexact_id_7'])) {
            $sanitary_values['searchexact_id_7'] = sanitize_text_field($input['searchexact_id_7']);
        }

        if (isset($input['tecdoc_root_cat_id_8'])) {
            $sanitary_values['tecdoc_root_cat_id_8'] = sanitize_text_field($input['tecdoc_root_cat_id_8']);
        }

        if (isset($input['single_product_compatible_cars_9'])) {
            $sanitary_values['single_product_compatible_cars_9'] = sanitize_text_field($input['single_product_compatible_cars_9']);
        }

        if (isset($input['tecdoc_api_base_url_10'])) {
            $sanitary_values['tecdoc_api_base_url_10'] = sanitize_text_field($input['tecdoc_api_base_url_10']);
        }

        if (isset($input['exclude_manufacturer_id_11'])) {
            $sanitary_values['exclude_manufacturer_id_11'] = sanitize_text_field($input['exclude_manufacturer_id_11']);
        }

        if (isset($input['hak_input_id_12'])) {
            $sanitary_values['hak_input_id_12'] = sanitize_text_field($input['hak_input_id_12']);
        }

        return $sanitary_values;
    }

    public function tecdoc_settings__section_info()
    {
    }

    public function country_code_according_to_iso_3166_0_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[country_code_according_to_iso_3166_0]" id="country_code_according_to_iso_3166_0" value="%s" placeholder="DE"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['country_code_according_to_iso_3166_0']) ? esc_attr($this->tecdoc_settings__options['country_code_according_to_iso_3166_0']) : '',
            __('For additional help, please visit this link <a href="https://en.wikipedia.org/wiki/ISO_3166-1" target="_blank">ISO 3166 codes</a>', 'tecdoc-woo')
        );
    }

    public function language_code_according_to_iso_639_1_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[language_code_according_to_iso_639_1]" id="language_code_according_to_iso_639_1" value="%s" placeholder="de"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['language_code_according_to_iso_639_1']) ? esc_attr($this->tecdoc_settings__options['language_code_according_to_iso_639_1']) : '',
            __('For additional help, please visit this link <a href="https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes" target="_blank">ISO 639-1 codes</a>', 'tecdoc-woo')
        );
    }

    public function tecdoc_provider_id_2_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[tecdoc_provider_id_2]" id="tecdoc_provider_id_2" value="%s" placeholder="12345"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['tecdoc_provider_id_2']) ? esc_attr($this->tecdoc_settings__options['tecdoc_provider_id_2']) : '',
            __('Please type providerID which you got from <a href="https://www.tecalliance.net" target="_blank">tecalliance.net</a>', 'tecdoc-woo')
        );
    }

    public function tecdoc_vehicle_type_3_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[tecdoc_vehicle_type_3]" id="tecdoc_vehicle_type_3" value="%s" placeholder="P"><p class="description">%s</p>
				<ul>
					<li>%s</li>
					<li>%s</li>
					<li>%s</li>
				</ul>
				',
            isset($this->tecdoc_settings__options['tecdoc_vehicle_type_3']) ? esc_attr($this->tecdoc_settings__options['tecdoc_vehicle_type_3']) : '',
            __('Please select vehicle type:', 'tecdoc-woo'),
            __('P: Passenger car', 'tecdoc-woo'),
            __('O: Commercial vehicle', 'tecdoc-woo'),
            __('L: Light commercial vehicle', 'tecdoc-woo')
        );
    }
    public function featured_manufacturer_id_4_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[featured_manufacturer_id_4]" id="featured_manufacturer_id_4" value="%s" placeholder="11;12;1314"><p class="description">%s</p>
			<p class="description">%s</p>',
            isset($this->tecdoc_settings__options['featured_manufacturer_id_4']) ? esc_attr($this->tecdoc_settings__options['featured_manufacturer_id_4']) : '',
            __('Please choose top brands ( car manufactures ) which will be displayed at the top of the select box.', 'tecdoc-woo'),
            __('* Please use (;) for delimiter! I.E. 11;12;13 and <u>please make sure that these brand ID is NOT in the exclude list below.</u>', 'tecdoc-woo')
        );
    }
    public function featured_manufacturer_checkbox_id_5_callback()
    {
        printf(
            '<input type="checkbox" name="tecdoc_settings__option_name[featured_manufacturer_checkbox_id_5]" id="featured_manufacturer_checkbox_id_5" value="1" %s>
			<p class="description">%s</p>',
            ( isset($this->tecdoc_settings__options['featured_manufacturer_checkbox_id_5']) && $this->tecdoc_settings__options['featured_manufacturer_checkbox_id_5'] === '1' ) ? 'checked' : '0',
            __('If checked it will show only featured brands, otherwise it will show featured and default brands', 'tecdoc-woo')
        );
    }
    public function brand_list_id_6_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[brand_list_id_6]" id="brand_list_id_6" value="%s" placeholder="11;12;1314"><p class="description">%s</p>
			<p class="description"></p>',
            isset($this->tecdoc_settings__options['brand_list_id_6']) ? esc_attr($this->tecdoc_settings__options['brand_list_id_6']) : '',
            __('Brand IDs which will be visible in TecDoc responses', 'tecdoc-woo'),
            __('* Please use (;) for delimiter! I.E. 11;12;13 ', 'tecdoc-woo')
        );
    }

    public function searchexact_id_7_callback()
    {
        printf(
            '<input type="checkbox" name="tecdoc_settings__option_name[searchexact_id_7]" id="searchexact_id_7" value="1" %s>
			<p class="description">%s</p>',
            ( isset($this->tecdoc_settings__options['searchexact_id_7']) && $this->tecdoc_settings__options['searchexact_id_7'] === '1' ) ? 'checked' : '0',
            __('If checked direct search will search exactly term what you type, otherwise they will search for similar terms', 'tecdoc-woo')
        );
    }

    public function tecdoc_root_cat_id_8_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[tecdoc_root_cat_id_8]" id="tecdoc_root_cat_id_8" value="%s" placeholder="1234"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['tecdoc_root_cat_id_8']) ? esc_attr($this->tecdoc_settings__options['tecdoc_root_cat_id_8']) : '',
            __('Please type TecDoc root category ID ( for addidtional help please contact plugin developer )', 'tecdoc-woo')
        );
    }

    public function single_product_compatible_cars_9_callback()
    {
        printf(
            '<input type="checkbox" name="tecdoc_settings__option_name[single_product_compatible_cars_9]" id="single_product_compatible_cars_9" value="1" %s>
			<p class="description">%s</p>',
            ( isset($this->tecdoc_settings__options['single_product_compatible_cars_9']) && $this->tecdoc_settings__options['single_product_compatible_cars_9'] === '1' ) ? 'checked' : '0',
            __('Display a list of product compatible cars in TecDoc tab on a single product', 'tecdoc-woo')
        );
    }

    public function tecdoc_api_base_url_10_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[tecdoc_api_base_url_10]" id="tecdoc_api_base_url_10" value="%s" placeholder="https://webservice-cs.tecdoc.net"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['tecdoc_api_base_url_10']) ? esc_attr($this->tecdoc_settings__options['tecdoc_api_base_url_10']) : 'https://webservice-cs.tecdoc.net',
            __('Base URL of TecDoc API without trailing slash, e.g. https://webservice-cs.tecdoc.net', 'tecdoc-woo')
        );
    }

    public function exclude_manufacturer_id_11_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[exclude_manufacturer_id_11]" id="exclude_manufacturer_id_11" value="%s" placeholder="11;12;13"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['exclude_manufacturer_id_11']) ? esc_attr($this->tecdoc_settings__options['exclude_manufacturer_id_11']) : '',
            __('Brand IDs which will NOT be visible in TecDoc responses', 'tecdoc-woo')
        );
    }

    public function hak_input_id_12_callback()
    {
        printf(
            '<input class="regular-text" type="text" name="tecdoc_settings__option_name[hak_input_id_12]" id="hak_input_id_12" value="%s" placeholder="Hak popust"><p class="description">%s</p>',
            isset($this->tecdoc_settings__options['hak_input_id_12']) ? esc_attr($this->tecdoc_settings__options['hak_input_id_12']) : '',
            __('Please type coupon name which will be visible on checkout page', 'tecdoc-woo')
        );
    }
    /**
     * Get options page settings
     * @return arr Settings array
     */
    public function get_settings()
    {
        $object = get_option('tecdoc_settings__option_name', []);
        $country_code = $object["country_code_according_to_iso_3166_0"];
        $lang_code = $object["language_code_according_to_iso_639_1"];
        $provider_id = $object["tecdoc_provider_id_2"];
        $vehicle_type = $object["tecdoc_vehicle_type_3"];
        $featured_ids = $object["featured_manufacturer_id_4"];
        $exclude_ids = $object["exclude_manufacturer_id_11"];
        $featured_ids_check = array_key_exists('featured_manufacturer_checkbox_id_5', $object) ? $object["featured_manufacturer_checkbox_id_5"] : 0;
        $brand_ids = array_key_exists('brand_list_id_6', $object) ? $object["brand_list_id_6"] : false;
        $search_mode_check = array_key_exists('searchexact_id_7', $object) ? $object["searchexact_id_7"] : 0;
        $tecdoc_root_cat = $object["tecdoc_root_cat_id_8"];
        $compatible_cars_list = array_key_exists('single_product_compatible_cars_9', $object) ? $object["single_product_compatible_cars_9"] : 0;
        $tecdoc_api_base = $object["tecdoc_api_base_url_10"];
        $hak_coupon_text =  array_key_exists('hak_input_id_12', $object) ? $object["hak_input_id_12"] : false;

        $output = array(
            'country_code' => $country_code,
            'language_code' => $lang_code,
            'provider_id' => $provider_id ,
            'vehicle_type' => $vehicle_type,
            'featured_ids' => $featured_ids,
            'exclude_ids' => $exclude_ids,
            'featured_ids_check' => $featured_ids_check,
            'siteurl' => $_SERVER['SERVER_NAME'],
            'brand_ids' => $brand_ids,
            'search_mode' => $search_mode_check,
            'tecdoc_root_cat' => $tecdoc_root_cat,
            'compatible_cars_list' => $compatible_cars_list,
            'tecdoc_api_base' => $tecdoc_api_base,
            'hak_coupon_text' => $hak_coupon_text,
            'top_brands' => __('Top Brands', 'tecdoc-woo'),
            'default_brands' => __('Default Brands', 'tecdoc-woo'),
            'model' => __('Model', 'tecdoc-woo'),
            'year' => __('Year', 'tecdoc-woo'),
            'type' => __('Type', 'tecdoc-woo'),
            'engine_type' => __('Engine Type', 'tecdoc-woo'),
            'power' => __('Power', 'tecdoc-woo'),
            'errmsg' => __('Please enter 4 or more alphanumeric characters', 'tecdoc-woo'),
            'success' => __('Active user!', 'tecdoc-woo'),
            'error' => __('Inactive user or wrong input data!', 'tecdoc-woo')
        );

        return $output;
    }
}
if (is_admin()) {
    $tecdoc_settings_ = new tecdocWooSettings();
}
/*
 * Retrieve this value with:
 * $tecdoc_settings__options = get_option( 'tecdoc_settings__option_name' ); // Array of All Options
 * $country_code_according_to_iso_3166_0 = $tecdoc_settings__options['country_code_according_to_iso_3166_0']; // Country code according to ISO 3166
 * $language_code_according_to_iso_639_1 = $tecdoc_settings__options['language_code_according_to_iso_639_1']; // Language code according to ISO 639
 * $tecdoc_provider_id_2 = $tecdoc_settings__options['tecdoc_provider_id_2']; // TecDoc Provider ID
 * $tecdoc_vehicle_type_3 = $tecdoc_settings__options['tecdoc_vehicle_type_3']; // TecDoc Vehicle Type
 */
