<?php

use Psr\Cache\CacheItemPoolInterface;

if (! defined('ABSPATH')) {
    exit;
}

/**
 * TecDoc API related methods
 */
class TecDoc_Api
{
    /**
     * TecDoc connection API URL
     * @var string
     */
    protected $tecdoc_api_url;

    /** @var CacheItemPoolInterface */
    protected $cache;


    public function __construct()
    {
        $settings = $this->get_settings();
        $this->tecdoc_api_url = array_key_exists('tecdoc_api_base', $settings) ? $settings['tecdoc_api_base'] . '/pegasus-3-0/services/TecdocToCatDLB.jsonEndpoint?js' : 'https://webservice-cs.tecdoc.net/pegasus-3-0/services/TecdocToCatDLB.jsonEndpoint?js';
    }

    /**
     * Get TecDoc connection settings
     * @return arr Settings array
     */
    function get_tecdoc_connection_settings()
    {
        return $this->get_settings();
    }

    /**
     * Fetch TecDoc API url
     * @return string API URL
     */
    function get_tecdoc_api_url()
    {
        return $this->tecdoc_api_url;
    }

    /**
   * Get options page settings
   * @return arr Settings array
   */
    public function get_settings()
    {
        $object = get_option('tecdoc_settings__option_name', []);
        $country_code = array_key_exists('country_code_according_to_iso_3166_0', $object) ? $object["country_code_according_to_iso_3166_0"] : '';
        $lang_code = array_key_exists('language_code_according_to_iso_639_1', $object) ? $object["language_code_according_to_iso_639_1"] : '';
        $provider_id = array_key_exists('tecdoc_provider_id_2', $object) ? $object["tecdoc_provider_id_2"] : '';
        $vehicle_type = array_key_exists('tecdoc_vehicle_type_3', $object) ? $object["tecdoc_vehicle_type_3"] : '';
        $featured_ids = array_key_exists('featured_manufacturer_id_4', $object) ? $object["featured_manufacturer_id_4"] : '';
        $featured_ids_check = array_key_exists('featured_manufacturer_checkbox_id_5', $object) ? $object["featured_manufacturer_checkbox_id_5"] : 0;
        $brand_ids = array_key_exists('brand_list_id_6', $object) ? $object["brand_list_id_6"] : false;
        $search_mode_check = array_key_exists('searchexact_id_7', $object) ? $object["searchexact_id_7"] : 0;
        $tecdoc_root_cat = array_key_exists('tecdoc_root_cat_id_8', $object) ? $object["tecdoc_root_cat_id_8"] : '';
        $compatible_cars_list = array_key_exists('single_product_compatible_cars_9', $object) ? $object["single_product_compatible_cars_9"] : 0;
        $tecdoc_api_base = array_key_exists('tecdoc_api_base_url_10', $object) ? $object["tecdoc_api_base_url_10"] : '';

        $output = array(
            'country_code' => $country_code,
            'language_code' => $lang_code,
            'provider_id' => $provider_id ,
            'vehicle_type' => $vehicle_type,
            'featured_ids' => $featured_ids,
            'featured_ids_check' => $featured_ids_check,
            'siteurl' => $_SERVER['SERVER_NAME'],
            'brand_ids' => $brand_ids,
            'search_mode' => $search_mode_check,
            'tecdoc_root_cat' => $tecdoc_root_cat,
            'compatible_cars_list' => $compatible_cars_list,
            'tecdoc_api_base' => $tecdoc_api_base,
            'top_brands' => __('Top Brands', 'tecdoc-woo'),
            'default_brands' => __('Default Brands', 'tecdoc-woo'),
            'model' => __('Model', 'tecdoc-woo'),
            'year' => __('Year', 'tecdoc-woo'),
            'type' => __('Type', 'tecdoc-woo'),
            'engine_type' => __('Engine Type', 'tecdoc-woo'),
            'power' => __('Power', 'tecdoc-woo')
        );

        return $output;
    }

    /**
     * Execute cURL with provided data
     * @param  array $post_data Data to be sent to TecDoc
     * @return array            Response array ()
     */
    function execute_curl($post_data, $httpheader = array(), $api_url = '')
    {
    	$cache = $this->getCache();
        $cache_key = 'api.' . md5(serialize($post_data) . serialize($httpheader) . $api_url);
        $cache_item = $cache->getItem($cache_key);

        if (!$cache_item->isHit()) {
            if ($api_url === '') {
                $api_url = $this->tecdoc_api_url;
            }

            $ch = curl_init($api_url);
            // Set cURL opts

            $curlOpts = array(
                CURLOPT_POST => true,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_HTTPHEADER => array(
                    'Content-Type: application/json'
                ),
                CURLOPT_POSTFIELDS => json_encode($post_data)
            );

            if (is_array($httpheader) && !empty($httpheader)) {
                $curlOpts[10023] = $httpheader;
            }

            curl_setopt_array($ch, $curlOpts);

            // Send the request
            $response = curl_exec($ch);

            // Check for errors
            if (!$response) {
                die(curl_error($ch));
            }

            // Decode the response
            $response = json_decode($response, true);

            if ($api_url === $this->tecdoc_api_url) {
                $data = array();

                if ($response['status'] === 200 && is_array($response['data']) && array_key_exists('array', $response['data'])) {
                    $data = $response['data']['array'];
                } else {
                    if ($response['status'] !== 200) {
                        print_r($post_data);
                        print_r($response);
                    }
                }

                $cache_item->set($data);
                $cache->save($cache_item);
            } else {
            	return $response;
            }
        }

        return $cache_item->get();
    }

	/**
	 * @return CacheItemPoolInterface
	 */
	public function getCache()
	{
		if (null === $this->cache) {
			$this->cache = ep_cache('tecdoc');
		}
		return $this->cache;
	}
}
