<?php

if (! defined('ABSPATH')) {
    exit;
}

/**
 * WooCommerce overrides class
 */
class tecdocEndpoints extends WP_REST_Controller
{
    /**
     * TecDoc connection params
     * @var array
     */
    protected $conn;

    /**
     * HAK rest api
     * @var string
     */
    protected $hak_api_url;

    /**
     * TecDoc API helper class
     * @var array
     */
    protected $tecdoc_api;

    /**
     * List of model types
     * @var array
     */
    protected $type_list = array();

    /**
     * Number of engine types left to parse
     * @var integer
     */
    protected $types_left_to_parse;

    public function __construct()
    {
        add_action('init', array($this, 'register_session'));
        add_action('rest_api_init', array($this, 'tecdocendpoint_init'));
        $this->hak_api_url = "https://web2.hak.hr/tehnickapomocapi/api/1.0/CheckMemberships";
    }

    /**
     * Check if session has already started
     * If not, register a new PHP session
     */
    function register_session()
    {
        if (!session_id()) {
            session_start();
        }
        // TecDoc instance
        $this->tecdoc_api = new TecDoc_Api;
        // Setup $conn array
        $this->conn = $this->tecdoc_api->get_tecdoc_connection_settings();
    }

    function tecdocendpoint_init()
    {
        $namespace_session = 'tecdoc/';
        $endpoint_session = '/session';
        register_rest_route($namespace_session, $endpoint_session, array(
            array(
            'methods'         => WP_REST_Server::CREATABLE,
            'callback'        => array( $this, 'set_car_restapi' ),
            'args'            => array(
            ),
        ),
            array(
            'methods'         => WP_REST_Server::DELETABLE,
            'callback'        => array( $this, 'delete_car_restapi' ),
            'args'            => $this->get_endpoint_args_for_item_schema(true),
            ),
        ));

        $this->manufacturers_endpoint_init();
        $this->model_endpoint_init();
        $this->type_endpoint_init();
        $this->engineinfo_endpoint_init();

        $this->hak_api_endpoint_init();
        $this->tecdoc_image_api_endpoint_init();
    }

    /* SESSION */
    function set_car_restapi(WP_REST_Request $request)
    {
    	if (!isset($_POST["manuID"]) || !is_numeric($_POST["manuID"]) || !isset($_POST["modID"]) || !is_numeric($_POST["modID"]) || !isset($_POST["typeID"]) || !is_numeric($_POST["typeID"])) {
    		exit();
    	}

        $_SESSION["manuID"] = $_POST["manuID"];
        $_SESSION["modID"] = $_POST["modID"];
        $_SESSION["typeID"] = $_POST["typeID"];
    }

    function delete_car_restapi(WP_REST_Request $request)
    {
        session_unset();
        session_destroy();
    }

    /* GET MANUFACTURES */
    function manufacturers_endpoint_init()
    {
        $namespace_manufacture = 'tecdoc/';
        $endpoint_manufacture = '/manufacturers';
        register_rest_route($namespace_manufacture, $endpoint_manufacture, array(
            array(
            'methods'         => WP_REST_Server::READABLE,
            'callback'        => array( $this, 'get_manufacturers_car_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }

    function get_manufacturers_car_restapi(WP_REST_Request $request)
    {
        $post_data = array(
            'getManufacturers' => array(
                "linkingTargetType" => $this->conn['vehicle_type'],
                "country" => $this->conn['country_code'],
                "lang" => $this->conn['language_code'],
                "provider" => $this->conn['provider_id']
            )
        );
        if (!empty($post_data) && is_array($post_data)) {
            $data = $this->tecdoc_api->execute_curl($post_data);
            return json_encode($data);
        } else {
            return 'Empty array or not valid data type';
        }
    }

    /* GET MODELS */
    function model_endpoint_init()
    {
        $namespace_model = 'tecdoc/';
        $endpoint_model = '/model';
        register_rest_route($namespace_model, $endpoint_model, array(
            array(
            'methods'         => WP_REST_Server::CREATABLE,
            'callback'        => array( $this, 'get_model_car_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }
    function get_model_car_restapi(WP_REST_Request $request)
    {
        $post_data = array(
            'getModelSeries' => array(
                "linkingTargetType" => $this->conn['vehicle_type'],
                "country" => $this->conn['country_code'],
                "lang" => $this->conn['language_code'],
                "provider" => $this->conn['provider_id'],
                "manuId" => $_POST["manuID"],
            )
        );


        if (!empty($post_data) && is_array($post_data)) {
            $data = $this->tecdoc_api->execute_curl($post_data);
            $data_by_series = [];

//            print_r($data);

            foreach ($data as &$item) {
                $series = explode(' ', $item['modelname'])[0];

                if (!array_key_exists($series, $data_by_series)) {
                    $data_by_series[$series] = [];
                }

                $data_by_series[$series][] = $item;
            }

//            print_r($data);

            return json_encode($data);
        } else {
            return 'Empty array or not vaild data type';
        }
    }

    /* GET TYPE */
    function type_endpoint_init()
    {
        $namespace_type = 'tecdoc/';
        $endpoint_type = '/type';
        register_rest_route($namespace_type, $endpoint_type, array(
            array(
            'methods'         => WP_REST_Server::CREATABLE,
            'callback'        => array( $this, 'get_type_car_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }
    function get_type_car_restapi(WP_REST_Request $request)
    {
        $post_data = array(
            'getVehicleIdsByCriteria' => array(
                "carType"  => $this->conn['vehicle_type'],
                "countriesCarSelection" => $this->conn['country_code'],
                "lang" => $this->conn['language_code'],
                "provider" => $this->conn['provider_id'],
                "countryGroupFlag" => false,
                "modId" => $_POST["modId"],
                "manuId" => $_POST["manuId"],
                "powerHpType" => true
            )
        );
        if (!empty($post_data) && is_array($post_data)) {
            $this->type_list = $this->tecdoc_api->execute_curl($post_data);

            $this->types_left_to_parse = count($this->type_list);

            foreach ($this->type_list as $key => $value) {
                $this->type_list[$key]['optGroupID'] = 'typeOpt';
            }

            $this->add_additional_motor_info();

            return json_encode($this->type_list);
        } else {
            return 'Empty array or not vaild data type';
        }
    }

    function add_additional_motor_info()
    {
        if (!is_array($this->type_list) || empty($this->type_list)) {
            return false;
        }

        $data_length = count($this->type_list);

        $car_ids = array();
        $parsed_types = 0;

        $iterations = $data_length === $this->types_left_to_parse ? $data_length : $this->types_left_to_parse;

        for ($i = $iterations - 1; $i >= 0; $i--) {
            if ($parsed_types === 25 || $this->types_left_to_parse === 0) {
                break;
            }

            if (!array_key_exists('carId', $this->type_list[$i])) {
                continue;
            }

            array_push($car_ids, $this->type_list[$i]['carId']);
            $parsed_types++;
            $this->types_left_to_parse--;
        }

        $this->get_additional_engine_info($car_ids);
    }

    function get_additional_engine_info($car_ids)
    {
        $post_data = array(
            'getVehicleByIds4' => array(
                "linkingTargetType"  => $this->conn['vehicle_type'],
                "articleCountry" => $this->conn['country_code'],
                "country" => $this->conn['country_code'],
                "countriesCarSelection" => $this->conn['country_code'],
                "lang" => $this->conn['language_code'],
                "provider" => $this->conn['provider_id'],
                'carIds' => array(
                  'array' => $car_ids,
                ),
            )
        );

        if (!empty($post_data) && is_array($post_data)) {
            $data = $this->tecdoc_api->execute_curl($post_data);

            if (!is_array($data) || empty($data)) {
                return false;
            }

            $this->vehicle_motor_callback($data);
        } else {
            return 'Empty array or not vaild data type';
        }
    }

    function vehicle_motor_callback($engine_data)
    {
        if (!is_array($engine_data) || empty($engine_data)) {
            return false;
        }

        // Add fetched additional motor data to typeList items
        for ($i = count($this->type_list) - 1; $i >= 0; $i--) {
            for ($j = count($engine_data) - 1; $j >= 0; $j--) {
                if ($this->type_list[$i]['carId'] === $engine_data[$j]['carId']) {
                    $this->type_list[$i]['vehicleDetails'] = $engine_data[$j]['vehicleDetails'];
                    break;
                }
            }
        }

        if ($this->types_left_to_parse > 0) {
            $this->add_additional_motor_info();
        }
    }

    /**
     * Get additional car engine info
     */
    function engineinfo_endpoint_init()
    {
        $namespace_info = 'tecdoc/';
        $endpoint_info = '/engine-info';
        register_rest_route($namespace_info, $endpoint_info, array(
            array(
            'methods'         => WP_REST_Server::CREATABLE,
            'callback'        => array( $this, 'get_additional_engine_info_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }
    function get_additional_engine_info_restapi(WP_REST_Request $request)
    {
        if (!isset($_POST['carIds']) || $_POST['carIds'] === '') {
            return false;
        }

        $car_ids = json_decode($_POST['carIds']);

        $post_data = array(
            'getVehicleByIds4' => array(
                "linkingTargetType"  => $this->conn['vehicle_type'],
                "articleCountry" => $this->conn['country_code'],
                "country" => $this->conn['country_code'],
                "countriesCarSelection" => $this->conn['country_code'],
                "lang" => $this->conn['language_code'],
                "provider" => $this->conn['provider_id'],
                'carIds' => array(
                  'array' => $_POST["carIds"],
                ),
            )
        );
        if (!empty($post_data) && is_array($post_data)) {
            $data = $this->tecdoc_api->execute_curl($post_data);
            return json_encode($data);
        } else {
            return 'Empty array or not vaild data type';
        }
    }

    /* HAK ( Hrvatski autoklub ) API  */
    function hak_api_endpoint_init()
    {
        $namespace_hak = 'hak/';
        $endpoint_hak = '/members';
        register_rest_route($namespace_hak, $endpoint_hak, array(
            array(
            'methods'         => WP_REST_Server::CREATABLE,
            'callback'        => array( $this, 'hak_member_check_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }

    function hak_member_check_restapi(WP_REST_Request $request)
    {
        global $woocommerce;

         $httpheader = array(
            'Content-Type: application/json',
            'Device: akresoweb',
            'Username: autokreso',
            'Token: 501stir092md4234xy54',
            'Cache-control: no-cache'
        );

        if (isset($_POST['memberId']) && isset($_POST['memberFirstName']) && isset($_POST['memberLastName']) && isset($_POST['hak_coupon'])) {
            $post_data = array(
                "first_name" => $_POST['memberLastName'],
                "last_name" => $_POST['memberFirstName'],
                "member_id" => $_POST['memberId'],
                "hak_coupon" => $_POST['hak_coupon']
            );
        } else {
            return 'Variables are not correctly set!';
        }

        if (!empty($post_data) && is_array($post_data) && !empty($httpheader)) {
            $data = $this->tecdoc_api->execute_curl($post_data, $httpheader, $this->hak_api_url);

            if ($data) {
                $hak_coupon_text = $post_data['hak_coupon'];
                define('IN_HAK_VALIDATION', true);
                $woocommerce->cart->add_discount(sanitize_text_field($hak_coupon_text));
            }

            return $data;
        } else {
            return 'Empty array or not vaild data type';
        }
    }

    /**
     * Initialize tecdoc image route
     */
    function tecdoc_image_api_endpoint_init()
    {
        $namespace_hak = 'image/';
        $endpoint_hak = '/get';
        register_rest_route($namespace_hak, $endpoint_hak, array(
            array(
            'methods'         => WP_REST_Server::READABLE,
            'callback'        => array( $this, 'tecdoc_image_fetch_restapi' ),
            'args'            => array(
            ),
        )
        ));
    }

    /**
     * Tecdoc image route callback
     * @param  WP_REST_Request $request WP REST request
     */
    function tecdoc_image_fetch_restapi(WP_REST_Request $request)
    {
        $image_url = $_GET['url'];
        $valid_image = $this->image_valid($image_url);

        if (!$valid_image) {
            return false;
        }

        $image = file_get_contents($image_url);

        header('Content-type: image/jpeg;');
        header("Content-Length: " . strlen($image));
        echo $image;
    }

    /**
     * Check if image is a valid
     * @param  string $file Image URL
     * @return boolean      True - url is an image, false - url is not an image
     */
    function image_valid($file)
    {
        $size = getimagesize($file);
        return (strtolower(substr($size['mime'], 0, 5)) == 'image' ? true : false);
    }
}
