<?php
return [];

use Ep\TecDoc\AjaxHandler;
use Ep\TecDoc\TecDocService;
use Ep\TecDoc\TecDocServiceFactory;

define('TECDOC_WOO_URL', plugin_dir_url(__FILE__));

require_once __DIR__ . '/includes/product.php';
require_once __DIR__ . '/includes/rewrite.php';
require_once __DIR__ . '/includes/search.php';

/**
 * Nakon učitavanja pluginova.
 */
add_action('plugins_loaded', function() {
    check_dependencies();
});

/**
 * Inicijalizacija.
 */
add_action('init', function() {
	// Proizvodi
	add_action('pre_get_posts', 'ep_tecdoc_product_cat_query', 10);
	add_action('the_posts', 'ep_tecdoc_product_get_posts', 10, 2);
	// Slike proizvoda
	add_filter('get_post_metadata', 'ep_tecdoc_product_metadata', 10, 3);
	add_filter('wp_get_attachment_image_src', 'ep_tecdoc_image_src', 10, 2);
});

/**
 * Aktivacija plugina.
 */
register_activation_hook(__FILE__, function() {
    check_dependencies();
	flush_rewrite_rules();
});

/**
 * Deaktivacija plugina.
 */
register_deactivation_hook(__FILE__, function() {
	flush_rewrite_rules();
});

/**
 * Registracija ajax handlera samo za ajax requestove.
 */
add_action('admin_init', function() {
	if (defined('DOING_AJAX')) {
		new AjaxHandler(ep_tecdoc_service());
	}
});

/**
 * Registriramo putanju do templateova u twig.
 */
add_filter('ep/twig/paths', function(array $paths = []) {
    $paths[] = __DIR__ . '/views';
    return $paths;
});

/**
 * Vraća TecDoc artikl za proizvod.
 *
 * @param $productId
 *
 * @return array
 */
function ep_tecdoc_article($productId)
{
	$cacheKey = sprintf('articles.product.%d', $productId);
	$cache = ep_cache('tecdoc');
	$item = $cache->getItem($cacheKey);

	if (!$item->isHit()) {
		/** @var WP_Post[] $posts */
		global $posts;

		if (is_array($posts)) {
			foreach ($posts as $post) {
				if ($post->ID === $productId && property_exists($post, 'tecdocArticle')) {
					return $post->tecdocArticle;
				}
			}
		}

		$articleKey = get_post_meta($productId, '_tecdoc_key', true);
		if (!$articleKey) return null;

		$tecdoc = ep_tecdoc_service();
		$articleId = $tecdoc->getArticleId($articleKey);
		if (!$articleId) return null;

		$articles = $tecdoc->getArticlesByIds([$articleId]);

		if (count($articles) > 0) {
			$article = $articles[0];
			$fullArticles = $tecdoc->getArticlesByGenericIds([$article['genericArticleId']]);

			if (count($fullArticles) > 0) {
				foreach ($fullArticles as $fullArticle) {
					if ($fullArticle['id'] === $article['id']) {
						$article = $fullArticle;
						break;
					}
				}
			}

			$item->set($article);
			$cache->save($item);
		}
	}

	return $item->get();
}

/**
 * Vraća HTTP klijent za komunikaciju s TecDoc-om.
 *
 * @return \GuzzleHttp\ClientInterface
 */
function ep_tecdoc_client()
{
    static $client;

    if (!isset($client)) {
        $client = new \GuzzleHttp\Client([
//            'base_uri' => 'https://webservice-cs.tecdoc.net',
            'base_uri' => TecDocService::SERVICE_URI,
            'headers' => [
                'Content-Type' => 'application/json',
            ],
            'timeout' => 5,
        ]);
    }

    return $client;
}

/**
 * Vraća instancu TecDoc servisa.
 *
 * @return TecDocService
 */
function ep_tecdoc_service()
{
	static $service;

	if (!isset($service)) {
		$factory = new TecDocServiceFactory();
        $service = $factory();
	}

	return $service;
}

/**
 * Provjerava da li imamo sve što nam treba.
 */
function check_dependencies()
{
	if (!defined('EP_CORE_VERSION')) {
	    require_once ABSPATH . 'wp-admin/includes/plugin.php';
	    deactivate_plugins(__FILE__, true);
		wp_die('EP TecDoc ovisi o EP Core. Instalirajte i aktivirajte ga.');
	}

	if (!function_exists('wc')) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		deactivate_plugins(__FILE__, true);
		wp_die('EP TecDoc ovisi o WooCommerce. Instalirajte i aktivirajte ga.');
	}
}

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-tecdoc-woo.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_tecdoc_woo()
{
    $plugin = new Tecdoc_Woo();
    $plugin->run();
}
run_tecdoc_woo();
